@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for dynamodb service client paginators.
 
@@ -7,7 +8,7 @@ Usage::
     import boto3
 
     from mypy_boto3_dynamodb import DynamoDBClient
-    from mypy_boto3_dynamodb import (
+    from mypy_boto3_dynamodb.paginator import (
         ListBackupsPaginator,
         ListTablesPaginator,
         ListTagsOfResourcePaginator,
@@ -24,12 +25,13 @@ Usage::
     scan_paginator: ScanPaginator = client.get_paginator("scan")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
+import sys
 from datetime import datetime
 from decimal import Decimal
-import sys
-from typing import Any, Dict, Iterator, List, Set, TYPE_CHECKING, Union
+from typing import Any, Dict, Iterator, List, Set, Union
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_dynamodb.type_defs import (
     ConditionTypeDef,
     ListBackupsOutputTypeDef,
@@ -57,7 +59,7 @@ __all__ = (
 
 class ListBackupsPaginator(Boto3Paginator):
     """
-    [Paginator.ListBackups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups)
+    [Paginator.ListBackups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.5/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups)
     """
 
     def paginate(
@@ -69,39 +71,39 @@ class ListBackupsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListBackupsOutputTypeDef]:
         """
-        [ListBackups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups.paginate)
+        [ListBackups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.5/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups.paginate)
         """
 
 
 class ListTablesPaginator(Boto3Paginator):
     """
-    [Paginator.ListTables documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables)
+    [Paginator.ListTables documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.5/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListTablesOutputTypeDef]:
         """
-        [ListTables.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables.paginate)
+        [ListTables.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.5/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables.paginate)
         """
 
 
 class ListTagsOfResourcePaginator(Boto3Paginator):
     """
-    [Paginator.ListTagsOfResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource)
+    [Paginator.ListTagsOfResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.5/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource)
     """
 
     def paginate(
         self, ResourceArn: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListTagsOfResourceOutputTypeDef]:
         """
-        [ListTagsOfResource.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource.paginate)
+        [ListTagsOfResource.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.5/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource.paginate)
         """
 
 
 class QueryPaginator(Boto3Paginator):
     """
-    [Paginator.Query documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dynamodb.html#DynamoDB.Paginator.Query)
+    [Paginator.Query documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.5/reference/services/dynamodb.html#DynamoDB.Paginator.Query)
     """
 
     def paginate(
@@ -144,13 +146,13 @@ class QueryPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[QueryOutputTypeDef]:
         """
-        [Query.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dynamodb.html#DynamoDB.Paginator.Query.paginate)
+        [Query.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.5/reference/services/dynamodb.html#DynamoDB.Paginator.Query.paginate)
         """
 
 
 class ScanPaginator(Boto3Paginator):
     """
-    [Paginator.Scan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dynamodb.html#DynamoDB.Paginator.Scan)
+    [Paginator.Scan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.5/reference/services/dynamodb.html#DynamoDB.Paginator.Scan)
     """
 
     def paginate(
@@ -192,5 +194,5 @@ class ScanPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ScanOutputTypeDef]:
         """
-        [Scan.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dynamodb.html#DynamoDB.Paginator.Scan.paginate)
+        [Scan.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.5/reference/services/dynamodb.html#DynamoDB.Paginator.Scan.paginate)
         """
