@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 """
 Main interface for dynamodb service client waiters.
 
@@ -7,7 +8,7 @@ Usage::
     import boto3
 
     from mypy_boto3_dynamodb import DynamoDBClient
-    from mypy_boto3_dynamodb import (
+    from mypy_boto3_dynamodb.waiter import (
         TableExistsWaiter,
         TableNotExistsWaiter,
     )
@@ -18,32 +19,30 @@ Usage::
     table_not_exists_waiter: TableNotExistsWaiter = client.get_waiter("table_not_exists")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import TYPE_CHECKING
 from botocore.waiter import Waiter as Boto3Waiter
-from mypy_boto3_dynamodb.type_defs import WaiterConfigTypeDef
 
+from mypy_boto3_dynamodb.type_defs import WaiterConfigTypeDef
 
 __all__ = ("TableExistsWaiter", "TableNotExistsWaiter")
 
 
 class TableExistsWaiter(Boto3Waiter):
     """
-    [Waiter.TableExists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dynamodb.html#DynamoDB.Waiter.TableExists)
+    [Waiter.TableExists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.5/reference/services/dynamodb.html#DynamoDB.Waiter.TableExists)
     """
 
     def wait(self, TableName: str, WaiterConfig: WaiterConfigTypeDef = None) -> None:
         """
-        [TableExists.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dynamodb.html#DynamoDB.Waiter.TableExists.wait)
+        [TableExists.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.5/reference/services/dynamodb.html#DynamoDB.Waiter.TableExists.wait)
         """
 
 
 class TableNotExistsWaiter(Boto3Waiter):
     """
-    [Waiter.TableNotExists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dynamodb.html#DynamoDB.Waiter.TableNotExists)
+    [Waiter.TableNotExists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.5/reference/services/dynamodb.html#DynamoDB.Waiter.TableNotExists)
     """
 
     def wait(self, TableName: str, WaiterConfig: WaiterConfigTypeDef = None) -> None:
         """
-        [TableNotExists.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/dynamodb.html#DynamoDB.Waiter.TableNotExists.wait)
+        [TableNotExists.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.5/reference/services/dynamodb.html#DynamoDB.Waiter.TableNotExists.wait)
         """
